@@ -2,28 +2,21 @@
 #
 #   file: lib/Test/Dist/Zilla.pm
 #
-
-#pod =encoding UTF-8
-#pod
-#pod =head1 COPYRIGHT AND LICENSE
-#pod
-#pod Copyright © 2015 Van de Bugger
-#pod
-#pod This file is part of perl-Test-Dist-Zilla.
-#pod
-#pod perl-Test-Dist-Zilla is free software: you can redistribute it and/or modify it under the terms
-#pod of the GNU General Public License as published by the Free Software Foundation, either version
-#pod 3 of the License, or (at your option) any later version.
-#pod
-#pod perl-Test-Dist-Zilla is distributed in the hope that it will be useful, but WITHOUT ANY
-#pod WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
-#pod PURPOSE. See the GNU General Public License for more details.
-#pod
-#pod You should have received a copy of the GNU General Public License along with
-#pod perl-Test-Dist-Zilla. If not, see <http://www.gnu.org/licenses/>.
-#pod
-#pod =cut
-
+#   Copyright © 2015 Van de Bugger
+#
+#   This file is part of perl-Test-Dist-Zilla.
+#
+#   perl-Test-Dist-Zilla is free software: you can redistribute it and/or modify it under the terms
+#   of the GNU General Public License as published by the Free Software Foundation, either version
+#   3 of the License, or (at your option) any later version.
+#
+#   perl-Test-Dist-Zilla is distributed in the hope that it will be useful, but WITHOUT ANY
+#   WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
+#   PURPOSE. See the GNU General Public License for more details.
+#
+#   You should have received a copy of the GNU General Public License along with
+#   perl-Test-Dist-Zilla. If not, see <http://www.gnu.org/licenses/>.
+#
 #   - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 
 #pod =head1 SYNOPSIS
@@ -32,9 +25,10 @@
 #pod
 #pod     use namespace::autoclean;
 #pod     use Test::Routine;
-#pod     with 'Test::Dist::Zilla';
 #pod     use Test::Deep qw{ cmp_deeply };
 #pod
+#pod     with 'Test::Dist::Zilla';
+#pod
 #pod     test 'Build' => sub {
 #pod         my ( $self ) = @_;
 #pod         my $expected = $self->expected;
@@ -66,24 +60,24 @@
 
 package Test::Dist::Zilla;
 
-use strict;
-use warnings;
 use namespace::autoclean;
+use strict;
 use utf8;
+use version 0.77;
+use warnings;
 
 # ABSTRACT: Test your Dist::Zilla plugin
-our $VERSION = 'v0.3.4'; # VERSION
+our $VERSION = 'v0.4.0'; # VERSION
 
-use Dist::Zilla::Tester::DieHard 0.002;     # DieHard v0.001 rethrows modified exception.
+use Dist::Zilla::Tester::DieHard v0.5.0;    # Need `release` method.
 use File::Temp qw{ tempdir };
 use Test::DZil qw{ dist_ini };
 use Test::More;
 use Test::Routine;
 use Try::Tiny;
 
-# `AutoPrereqs` hints:
-use Software::License::Perl_5   ();
-use Moose 2.0800                ();
+# REQUIRE: Software::License::Perl_5
+# REQUIRE: Moose 2.0800
     # ^ Test will likely fail with older Moose.
     #   Starting from 2.0800 "Roles can now override methods from other roles…".
 
@@ -93,7 +87,7 @@ use Moose 2.0800                ();
 #pod
 #pod Hash of distribution options: C<name>, C<version> C<abstract>, etc. to write to the test's
 #pod F<dist.ini>. This attribute is passed to C<dist_ini> as C<\%root_config> argument, see
-#pod L<Test::DZill/"dist_ini">.
+#pod L<Test::DZil/"dist_ini">.
 #pod
 #pod C<HashRef>. Default value can be overridden by defining C<_build_dist> builder.
 #pod
@@ -103,7 +97,7 @@ use Moose 2.0800                ();
 #pod         name     => 'Assa',
 #pod         version  => '0.007',
 #pod         author   => 'John Doe',
-#pod         …
+#pod         ...
 #pod     } };
 #pod
 #pod     run_me {
@@ -111,9 +105,9 @@ use Moose 2.0800                ();
 #pod             name     => 'Assa',
 #pod             version  => '0.007',
 #pod             author   => 'John Doe',
-#pod             …
+#pod             ...
 #pod         },
-#pod         …
+#pod         ...
 #pod     };
 #pod
 #pod TODO: Merge specified keys into default?
@@ -144,7 +138,7 @@ sub _build_dist {
 #pod =attr C<plugins>
 #pod
 #pod Plugin configuration to write to the test's F<dist.ini>. Attribute is passed to C<dist_ini> as
-#pod C<@plugins> argument, see L<Test::DZill/"dist_ini">.
+#pod C<@plugins> argument, see L<Test::DZil/"dist_ini">.
 #pod
 #pod C<ArrayRef>, optional. Default value is empty array (i. e. no plugins), it can be overridden by
 #pod defining C<_build_plugins> builder.
@@ -164,7 +158,7 @@ sub _build_dist {
 #pod                 'replacer' => 'replace_with_comment',
 #pod             } ],
 #pod         ],
-#pod         …
+#pod         ...
 #pod     };
 #pod
 #pod =cut
@@ -188,8 +182,7 @@ sub _build_plugins {
 #pod contents. A file content may be specified by a (possibly multi-line) string or by array of lines
 #pod (newlines are optional and will be appended if missed).
 #pod
-#pod Note: Do not specify F<dist.ini> file in C<files> — F<dist.ini> is generated from C<dist> and
-#pod C<plugins> attributes.
+#pod Note: Explicitly specified F<dist.ini> file overrides C<dist> and C<plugins> attributes.
 #pod
 #pod C<HashRef>, optional, default value is empty hash (i. e. no files).
 #pod
@@ -207,10 +200,10 @@ sub _build_plugins {
 #pod
 #pod     run_me {
 #pod         files => {
-#pod             'lib/Assa.pod' => [ … ],
-#pod             …
+#pod             'lib/Assa.pod' => [ ... ],
+#pod             ...
 #pod         },
-#pod         …
+#pod         ...
 #pod     };
 #pod
 #pod =cut
@@ -233,7 +226,7 @@ sub _build_files {
 #pod Test-enabled C<Dist::Zilla> instance (or C<DieHard> "survivor" object, if C<Dist::Zilla>
 #pod constructing fails).
 #pod
-#pod By default C<Dist::Zilla> instance is created by calling C<< Builder->from_config( … ) >> with
+#pod By default C<Dist::Zilla> instance is created by calling C<< Builder->from_config( ... ) >> with
 #pod appropriate arguments. Thanks to C<Dist::Zilla::Tester::DieHard>, it is never dies even if
 #pod constructing fails, so C<< $self->tzil->log_message >> returns the log messages in anyway.
 #pod
@@ -268,7 +261,7 @@ has tzil => (
     lazy        => 1,
     builder     => '_build_tzil',
     init_arg    => undef,
-    handles     => [ qw{ build } ],
+    handles     => [ qw{ build release } ],
 );
 
 sub _build_tzil {
@@ -319,12 +312,12 @@ sub _build_tzil {
 #pod     test 'Build' => sub {
 #pod         my ( $self ) = @_;
 #pod         $self->build();
-#pod         …
+#pod         ...
 #pod     };
 #pod
 #pod =cut
 
-around build => sub {
+around [ qw{ build release } ] => sub {
     my ( $orig, $self, @args ) = @_;
     my $ret;
     try {
@@ -346,7 +339,7 @@ around build => sub {
 #pod         if ( $self->exception ) {
 #pod             plan skip_all => 'exception thrown';
 #pod         };
-#pod         …
+#pod         ...
 #pod     };
 #pod
 #pod =cut
@@ -370,7 +363,7 @@ has exception => (
 #pod Examples:
 #pod
 #pod     run_me {
-#pod         …,
+#pod         ...,
 #pod         expected => {
 #pod             exception => "Aborting...\n",
 #pod             messages  => [
@@ -443,7 +436,7 @@ sub messages {
 #pod
 #pod     run_me {
 #pod         message_filter => sub { map( { $_ =~ s{^\[.*?\] }{}r ) @_ ) },
-#pod         …
+#pod         ...
 #pod     };
 #pod
 #pod =cut
@@ -519,6 +512,17 @@ sub _anno_text {
 #pod = L<Dist::Zilla::Tester::DieHard>
 #pod = L<Test::DZil/"dist_ini">
 #pod
+#pod =head1 COPYRIGHT AND LICENSE
+#pod
+#pod Copyright (C) 2015 Van de Bugger
+#pod
+#pod License GPLv3+: The GNU General Public License version 3 or later
+#pod <http://www.gnu.org/licenses/gpl-3.0.txt>.
+#pod
+#pod This is free software: you are free to change and redistribute it. There is
+#pod NO WARRANTY, to the extent permitted by law.
+#pod
+#pod
 #pod =cut
 
 # end of file #
@@ -535,7 +539,7 @@ Test::Dist::Zilla - Test your Dist::Zilla plugin
 
 =head1 VERSION
 
-Version v0.3.4, released on 2015-10-10 22:27 UTC.
+Version v0.4.0, released on 2015-10-27 08:40 UTC.
 
 =head1 SYNOPSIS
 
@@ -543,9 +547,10 @@ Version v0.3.4, released on 2015-10-10 22:27 UTC.
 
     use namespace::autoclean;
     use Test::Routine;
-    with 'Test::Dist::Zilla';
     use Test::Deep qw{ cmp_deeply };
 
+    with 'Test::Dist::Zilla';
+
     test 'Build' => sub {
         my ( $self ) = @_;
         my $expected = $self->expected;
@@ -579,7 +584,7 @@ specific roles, for example, C<Test::Dist::Zilla::Build>.
 
 Hash of distribution options: C<name>, C<version> C<abstract>, etc. to write to the test's
 F<dist.ini>. This attribute is passed to C<dist_ini> as C<\%root_config> argument, see
-L<Test::DZill/"dist_ini">.
+L<Test::DZil/"dist_ini">.
 
 C<HashRef>. Default value can be overridden by defining C<_build_dist> builder.
 
@@ -589,7 +594,7 @@ Examples:
         name     => 'Assa',
         version  => '0.007',
         author   => 'John Doe',
-        …
+        ...
     } };
 
     run_me {
@@ -597,9 +602,9 @@ Examples:
             name     => 'Assa',
             version  => '0.007',
             author   => 'John Doe',
-            …
+            ...
         },
-        …
+        ...
     };
 
 TODO: Merge specified keys into default?
@@ -607,7 +612,7 @@ TODO: Merge specified keys into default?
 =head2 C<plugins>
 
 Plugin configuration to write to the test's F<dist.ini>. Attribute is passed to C<dist_ini> as
-C<@plugins> argument, see L<Test::DZill/"dist_ini">.
+C<@plugins> argument, see L<Test::DZil/"dist_ini">.
 
 C<ArrayRef>, optional. Default value is empty array (i. e. no plugins), it can be overridden by
 defining C<_build_plugins> builder.
@@ -627,7 +632,7 @@ Examples:
                 'replacer' => 'replace_with_comment',
             } ],
         ],
-        …
+        ...
     };
 
 =head2 C<files>
@@ -636,8 +641,7 @@ Hash of source files to add to the test's distribution source. Keys are file nam
 contents. A file content may be specified by a (possibly multi-line) string or by array of lines
 (newlines are optional and will be appended if missed).
 
-Note: Do not specify F<dist.ini> file in C<files> — F<dist.ini> is generated from C<dist> and
-C<plugins> attributes.
+Note: Explicitly specified F<dist.ini> file overrides C<dist> and C<plugins> attributes.
 
 C<HashRef>, optional, default value is empty hash (i. e. no files).
 
@@ -655,10 +659,10 @@ Examples:
 
     run_me {
         files => {
-            'lib/Assa.pod' => [ … ],
-            …
+            'lib/Assa.pod' => [ ... ],
+            ...
         },
-        …
+        ...
     };
 
 =head2 C<tzil>
@@ -666,7 +670,7 @@ Examples:
 Test-enabled C<Dist::Zilla> instance (or C<DieHard> "survivor" object, if C<Dist::Zilla>
 constructing fails).
 
-By default C<Dist::Zilla> instance is created by calling C<< Builder->from_config( … ) >> with
+By default C<Dist::Zilla> instance is created by calling C<< Builder->from_config( ... ) >> with
 appropriate arguments. Thanks to C<Dist::Zilla::Tester::DieHard>, it is never dies even if
 constructing fails, so C<< $self->tzil->log_message >> returns the log messages in anyway.
 
@@ -702,7 +706,7 @@ Exception occurred during build, or C<undef> is no exception were occurred.
         if ( $self->exception ) {
             plan skip_all => 'exception thrown';
         };
-        …
+        ...
     };
 
 =head2 C<expected>
@@ -716,7 +720,7 @@ C<HashRef>, required.
 Examples:
 
     run_me {
-        …,
+        ...,
         expected => {
             exception => "Aborting...\n",
             messages  => [
@@ -753,7 +757,7 @@ Drop plugin names from messages:
 
     run_me {
         message_filter => sub { map( { $_ =~ s{^\[.*?\] }{}r ) @_ ) },
-        …
+        ...
     };
 
 =head1 OBJECT METHODS
@@ -771,7 +775,7 @@ Examples:
     test 'Build' => sub {
         my ( $self ) = @_;
         $self->build();
-        …
+        ...
     };
 
 =head2 C<messages>
@@ -809,19 +813,12 @@ Van de Bugger <van.de.bugger@gmail.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright © 2015 Van de Bugger
+Copyright (C) 2015 Van de Bugger
 
-This file is part of perl-Test-Dist-Zilla.
+License GPLv3+: The GNU General Public License version 3 or later
+<http://www.gnu.org/licenses/gpl-3.0.txt>.
 
-perl-Test-Dist-Zilla is free software: you can redistribute it and/or modify it under the terms
-of the GNU General Public License as published by the Free Software Foundation, either version
-3 of the License, or (at your option) any later version.
-
-perl-Test-Dist-Zilla is distributed in the hope that it will be useful, but WITHOUT ANY
-WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
-PURPOSE. See the GNU General Public License for more details.
-
-You should have received a copy of the GNU General Public License along with
-perl-Test-Dist-Zilla. If not, see <http://www.gnu.org/licenses/>.
+This is free software: you are free to change and redistribute it. There is
+NO WARRANTY, to the extent permitted by law.
 
 =cut
