@@ -2,39 +2,34 @@
 #
 #   file: lib/Test/Dist/Zilla/BuiltFiles.pm
 #
-
-#pod =encoding UTF-8
-#pod
-#pod =head1 COPYRIGHT AND LICENSE
-#pod
-#pod Copyright © 2015 Van de Bugger
-#pod
-#pod This file is part of perl-Test-Dist-Zilla.
-#pod
-#pod perl-Test-Dist-Zilla is free software: you can redistribute it and/or modify it under the terms
-#pod of the GNU General Public License as published by the Free Software Foundation, either version
-#pod 3 of the License, or (at your option) any later version.
-#pod
-#pod perl-Test-Dist-Zilla is distributed in the hope that it will be useful, but WITHOUT ANY
-#pod WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
-#pod PURPOSE. See the GNU General Public License for more details.
-#pod
-#pod You should have received a copy of the GNU General Public License along with
-#pod perl-Test-Dist-Zilla. If not, see <http://www.gnu.org/licenses/>.
-#pod
-#pod =cut
-
+#   Copyright © 2015 Van de Bugger
+#
+#   This file is part of perl-Test-Dist-Zilla.
+#
+#   perl-Test-Dist-Zilla is free software: you can redistribute it and/or modify it under the terms
+#   of the GNU General Public License as published by the Free Software Foundation, either version
+#   3 of the License, or (at your option) any later version.
+#
+#   perl-Test-Dist-Zilla is distributed in the hope that it will be useful, but WITHOUT ANY
+#   WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
+#   PURPOSE. See the GNU General Public License for more details.
+#
+#   You should have received a copy of the GNU General Public License along with
+#   perl-Test-Dist-Zilla. If not, see <http://www.gnu.org/licenses/>.
+#
 #   - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 
 #pod =head1 SYNOPSIS
 #pod
-#pod     package ManifestTester;
+#pod     package ManifestTester2;
 #pod
-#pod     use Moose;
-#pod     with 'Test::Dist::Zilla::Build';
-#pod     with 'Test::Dist::Zilla::BuiltFiles';
 #pod     use Test::Deep qw{ cmp_deeply re };
 #pod     use Test::More;
+#pod     use Test::Routine;
+#pod     use Test::Routine::Util;
+#pod
+#pod     with 'Test::Dist::Zilla::Build';
+#pod     with 'Test::Dist::Zilla::BuiltFiles';
 #pod
 #pod     run_me 'A test' => {
 #pod         plugins => [
@@ -53,7 +48,7 @@
 #pod                     'META.json',
 #pod                 ],
 #pod             },
-#pod         };
+#pod         },
 #pod     };
 #pod
 #pod     exit( 0 );
@@ -69,12 +64,13 @@
 
 package Test::Dist::Zilla::BuiltFiles;
 
-use strict;
-use warnings;
 use namespace::autoclean;
+use strict;
+use version 0.77;
+use warnings;
 
 # ABSTRACT: TODO: Test your Dist::Zilla plugin in I<build> action
-our $VERSION = 'v0.3.4'; # VERSION
+our $VERSION = 'v0.4.0'; # VERSION
 
 use Test::Routine;
 
@@ -164,6 +160,17 @@ test 'BuiltFiles' => sub {
 #pod = L<Test::Deep/"$ok = cmp_deeply($got, $expected, $name)">
 #pod = L<Test::Routine>
 #pod
+#pod =head1 COPYRIGHT AND LICENSE
+#pod
+#pod Copyright (C) 2015 Van de Bugger
+#pod
+#pod License GPLv3+: The GNU General Public License version 3 or later
+#pod <http://www.gnu.org/licenses/gpl-3.0.txt>.
+#pod
+#pod This is free software: you are free to change and redistribute it. There is
+#pod NO WARRANTY, to the extent permitted by law.
+#pod
+#pod
 #pod =cut
 
 # end of file #
@@ -180,17 +187,19 @@ Test::Dist::Zilla::BuiltFiles - TODO: Test your Dist::Zilla plugin in I<build> a
 
 =head1 VERSION
 
-Version v0.3.4, released on 2015-10-10 22:27 UTC.
+Version v0.4.0, released on 2015-10-27 08:40 UTC.
 
 =head1 SYNOPSIS
 
-    package ManifestTester;
+    package ManifestTester2;
 
-    use Moose;
-    with 'Test::Dist::Zilla::Build';
-    with 'Test::Dist::Zilla::BuiltFiles';
     use Test::Deep qw{ cmp_deeply re };
     use Test::More;
+    use Test::Routine;
+    use Test::Routine::Util;
+
+    with 'Test::Dist::Zilla::Build';
+    with 'Test::Dist::Zilla::BuiltFiles';
 
     run_me 'A test' => {
         plugins => [
@@ -209,7 +218,7 @@ Version v0.3.4, released on 2015-10-10 22:27 UTC.
                     'META.json',
                 ],
             },
-        };
+        },
     };
 
     exit( 0 );
@@ -269,19 +278,12 @@ Van de Bugger <van.de.bugger@gmail.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright © 2015 Van de Bugger
+Copyright (C) 2015 Van de Bugger
 
-This file is part of perl-Test-Dist-Zilla.
+License GPLv3+: The GNU General Public License version 3 or later
+<http://www.gnu.org/licenses/gpl-3.0.txt>.
 
-perl-Test-Dist-Zilla is free software: you can redistribute it and/or modify it under the terms
-of the GNU General Public License as published by the Free Software Foundation, either version
-3 of the License, or (at your option) any later version.
-
-perl-Test-Dist-Zilla is distributed in the hope that it will be useful, but WITHOUT ANY
-WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
-PURPOSE. See the GNU General Public License for more details.
-
-You should have received a copy of the GNU General Public License along with
-perl-Test-Dist-Zilla. If not, see <http://www.gnu.org/licenses/>.
+This is free software: you are free to change and redistribute it. There is
+NO WARRANTY, to the extent permitted by law.
 
 =cut
